// מאזין להודעות מה-content script
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    console.log('התקבלה בקשה:', request);
    
    if (request.action === 'getVideoInfo') {
        console.log('בודק מידע על וידאו:', request.url);
        
        // בדיקה שה-URL תקין
        if (!request.url) {
            console.error('URL חסר');
            sendResponse({ success: false, error: 'URL חסר' });
            return true;
        }

        // הגדרת timeout לבקשת הרשת
        const controller = new AbortController();
        const timeoutId = setTimeout(() => controller.abort(), 30000); // timeout אחרי 30 שניות

        fetch(request.url, {
            method: 'HEAD',
            credentials: 'include',
            signal: controller.signal
        })
        .then(response => {
            clearTimeout(timeoutId);
            console.log('תשובה מהשרת:', response);
            
            if (!response.ok) {
                throw new Error(`שגיאת שרת: ${response.status}`);
            }
            
            const contentType = response.headers.get('content-type');
            console.log('סוג תוכן:', contentType);
            
            // בדיקה מורחבת ומדויקת יותר של סוג הקובץ
            const videoTypes = [
                'video/',
                'application/x-matroska',    // MKV
                'application/mp4',           // MP4
                'application/quicktime',     // MOV
                'application/x-msvideo'      // AVI
            ];
            
            const isVideo = contentType && (
                videoTypes.some(type => contentType.toLowerCase().includes(type)) ||
                (contentType.includes('application/octet-stream') && 
                 request.url.toLowerCase().match(/\.(mp4|mkv|avi|mov|webm)$/))
            );
            
            if (!isVideo) {
                throw new Error(`סוג קובץ לא תקין: ${contentType}`);
            }

            // בדיקת גודל הקובץ
            const contentLength = response.headers.get('content-length');
            if (contentLength && parseInt(contentLength) === 0) {
                throw new Error('קובץ ריק');
            }
            
            sendResponse({
                success: true,
                contentType: contentType,
                contentLength: contentLength,
                url: request.url
            });
        })
        .catch(error => {
            clearTimeout(timeoutId);
            console.error('שגיאה:', error);

            // טיפול בסוגים שונים של שגיאות
            let errorMessage = error.message || 'שגיאה בגישה לקובץ הווידאו';
            
            if (error.name === 'AbortError') {
                errorMessage = 'תם הזמן המוקצב לטעינת הווידאו';
            } else if (!navigator.onLine) {
                errorMessage = 'אין חיבור לאינטרנט';
            } else if (error.message.includes('Failed to fetch')) {
                errorMessage = 'לא ניתן לגשת לשרת';
            }

            sendResponse({ 
                success: false, 
                error: errorMessage
            });
        });
        
        return true;  // שומר את ה-sendResponse פעיל
    }
});

// האזנה למצב החיבור לרשת
chrome.runtime.onStartup.addListener(() => {
    window.addEventListener('online', () => {
        console.log('החיבור לאינטרנט חזר');
    });
    
    window.addEventListener('offline', () => {
        console.log('אין חיבור לאינטרנט');
    });
});
