document.addEventListener('DOMContentLoaded', async () => {
    // טעינת ההגדרות הנוכחיות
    const settings = await chrome.storage.sync.get({
        openInNewTab: false,
        defaultPosition: 'bottom-right'
    });

    // הגדרת מצב הצ'קבוקס
    const openInNewTabCheckbox = document.getElementById('openInNewTab');
    openInNewTabCheckbox.checked = settings.openInNewTab;

    // הגדרת המיקום הנבחר
    const selectedPosition = document.querySelector(`.position-option[data-position="${settings.defaultPosition}"]`);
    if (selectedPosition) {
        selectedPosition.classList.add('selected');
    }

    // הוספת אירוע שינוי לצ'קבוקס
    openInNewTabCheckbox.addEventListener('change', async (e) => {
        await chrome.storage.sync.set({
            openInNewTab: e.target.checked
        });
        
        // אנימציית מעבר לצ'קבוקס
        const slider = e.target.nextElementSibling;
        slider.style.transition = 'background-color 0.3s ease';
        
        // הוספת אפקט גלים בלחיצה
        const ripple = document.createElement('div');
        ripple.style.cssText = `
            position: absolute;
            width: 100%;
            height: 100%;
            border-radius: 24px;
            background: currentColor;
            opacity: 0.1;
            transform: scale(0);
            animation: ripple 0.6s linear;
        `;
        slider.appendChild(ripple);
        setTimeout(() => ripple.remove(), 600);
    });

    // הוספת אירועי לחיצה לאפשרויות המיקום
    const positionOptions = document.querySelectorAll('.position-option');
    positionOptions.forEach(option => {
        option.addEventListener('click', async () => {
            // הסרת הבחירה הקודמת
            document.querySelector('.position-option.selected')?.classList.remove('selected');
            
            // הוספת הבחירה החדשה
            option.classList.add('selected');

            // שמירת ההגדרה החדשה
            await chrome.storage.sync.set({
                defaultPosition: option.dataset.position
            });

            // אנימציית בחירה
            const icon = option.querySelector('.material-icons-round');
            icon.style.transform = 'scale(1.2)';
            setTimeout(() => {
                icon.style.transform = 'scale(1)';
            }, 200);
        });

        // הוספת אפקט hover מתקדם
        option.addEventListener('mouseover', () => {
            const icon = option.querySelector('.material-icons-round');
            icon.style.transform = 'scale(1.1)';
        });

        option.addEventListener('mouseout', () => {
            const icon = option.querySelector('.material-icons-round');
            icon.style.transform = 'scale(1)';
        });
    });

    // הוספת אירוע לחיצה לקישור הגיטהאב
    document.getElementById('openGithub').addEventListener('click', (e) => {
        e.preventDefault();
        chrome.tabs.create({
            url: 'https://github.com/yourusername/gmail-video-viewer'
        });
    });

    // הוספת אנימציית ripple לסטייל
    const style = document.createElement('style');
    style.textContent = `
        @keyframes ripple {
            0% {
                transform: scale(0);
                opacity: 0.1;
            }
            100% {
                transform: scale(2);
                opacity: 0;
            }
        }
    `;
    document.head.appendChild(style);
});
